@@ -37,6 +37,12 @@
 #include <string.h>
 #include <stdlib.h>
 
+gboolean
+eel_uri_is_favorites (const gchar *uri)
+{
+    return g_str_has_prefix (uri, "favorites:");
+}
+
 gboolean
 eel_uri_is_trash (const char *uri)
 {
