@@ -27,6 +27,7 @@
 #include "nautilus-file-private.h"
 #include "nautilus-file-utilities.h"
 #include "nautilus-search-directory.h"
+#include "nautilus-favorite-directory.h"
 #include "nautilus-search-directory-file.h"
 #include "nautilus-vfs-file.h"
 #include "nautilus-global-preferences.h"
@@ -66,14 +67,10 @@ static void               set_directory_location (NautilusDirectory *directory,
 G_DEFINE_TYPE (NautilusDirectory, nautilus_directory, G_TYPE_OBJECT);
 
 static gboolean
-real_contains_file (NautilusDirectory *self,
+real_contains_file (NautilusDirectory *directory,
                     NautilusFile      *file)
 {
-    NautilusDirectory *directory;
-
-    directory = nautilus_file_get_directory (file);
-
-    return directory == self;
+    return file->details->directory == directory;
 }
 
 static gboolean
@@ -805,6 +802,19 @@ nautilus_directory_is_in_recent (NautilusDirectory *directory)
     return g_file_has_uri_scheme (directory->details->location, "recent");
 }
 
+gboolean
+nautilus_directory_is_in_starred (NautilusDirectory *directory)
+{
+    g_assert (NAUTILUS_IS_DIRECTORY (directory));
+
+    if (directory->details->location == NULL)
+    {
+        return FALSE;
+    }
+
+    return g_file_has_uri_scheme (directory->details->location, "favorites");
+}
+
 gboolean
 nautilus_directory_is_in_admin (NautilusDirectory *directory)
 {
@@ -1093,7 +1103,7 @@ call_files_added_free_list (gpointer key,
 }
 
 static void
-call_files_changed_common (NautilusDirectory *self,
+call_files_changed_common (NautilusDirectory *directory,
                            GList             *file_list)
 {
     GList *node;
@@ -1101,18 +1111,15 @@ call_files_changed_common (NautilusDirectory *self,
 
     for (node = file_list; node != NULL; node = node->next)
     {
-        NautilusDirectory *directory;
-
         file = node->data;
-        directory = nautilus_file_get_directory (file);
-
-        if (directory == self)
+        if (file->details->directory == directory)
         {
-            nautilus_directory_add_file_to_work_queue (self, file);
+            nautilus_directory_add_file_to_work_queue (directory,
+                                                       file);
         }
     }
-    nautilus_directory_async_state_changed (self);
-    nautilus_directory_emit_change_signals (self, file_list);
+    nautilus_directory_async_state_changed (directory);
+    nautilus_directory_emit_change_signals (directory, file_list);
 }
 
 static void
@@ -1299,10 +1306,6 @@ nautilus_directory_notify_files_changed (GList *files)
         file = nautilus_file_get_existing (location);
         if (file != NULL)
         {
-            NautilusDirectory *directory;
-
-            directory = nautilus_file_get_directory (file);
-
             /* Tell it to re-get info now, and later emit
              * a changed signal.
              */
@@ -1310,7 +1313,9 @@ nautilus_directory_notify_files_changed (GList *files)
             file->details->link_info_is_up_to_date = FALSE;
             nautilus_file_invalidate_extension_info_internal (file);
 
-            hash_table_list_prepend (changed_lists, directory, file);
+            hash_table_list_prepend (changed_lists,
+                                     file->details->directory,
+                                     file);
         }
     }
 
@@ -1352,14 +1357,11 @@ nautilus_directory_notify_files_removed (GList *files)
         file = nautilus_file_get_existing (location);
         if (file != NULL && !nautilus_file_rename_in_progress (file))
         {
-            NautilusDirectory *directory;
-
-            directory = nautilus_file_get_directory (file);
-
             /* Mark it gone and prepare to send the changed signal. */
             nautilus_file_mark_gone (file);
             hash_table_list_prepend (changed_lists,
-                                     directory, nautilus_file_ref (file));
+                                     file->details->directory,
+                                     nautilus_file_ref (file));
         }
         nautilus_file_unref (file);
     }
@@ -1517,12 +1519,10 @@ nautilus_directory_moved (const char *old_uri,
     list = nautilus_directory_moved_internal (old_location, new_location);
     for (node = list; node != NULL; node = node->next)
     {
-        NautilusDirectory *directory;
-
         file = NAUTILUS_FILE (node->data);
-        directory = nautilus_file_get_directory (file);
-
-        hash_table_list_prepend (hash, directory, nautilus_file_ref (file));
+        hash_table_list_prepend (hash,
+                                 file->details->directory,
+                                 nautilus_file_ref (file));
     }
     nautilus_file_list_free (list);
 
@@ -1568,14 +1568,14 @@ nautilus_directory_notify_files_moved (GList *file_pairs)
         file = nautilus_file_get_existing (to_location);
         if (file != NULL)
         {
-            NautilusDirectory *directory;
-
-            directory = nautilus_file_get_directory (file);
-
             /* Mark it gone and prepare to send the changed signal. */
             nautilus_file_mark_gone (file);
-            hash_table_list_prepend (changed_lists, directory, file);
-            collect_parent_directories (parent_directories, directory);
+            new_directory = file->details->directory;
+            hash_table_list_prepend (changed_lists,
+                                     new_directory,
+                                     file);
+            collect_parent_directories (parent_directories,
+                                        new_directory);
         }
 
         /* Update any directory objects that are affected. */
@@ -1583,11 +1583,10 @@ nautilus_directory_notify_files_moved (GList *file_pairs)
                                                             to_location);
         for (node = affected_files; node != NULL; node = node->next)
         {
-            NautilusDirectory *directory;
-
             file = NAUTILUS_FILE (node->data);
-            directory = nautilus_file_get_directory (file);
-            hash_table_list_prepend (changed_lists, directory, file);
+            hash_table_list_prepend (changed_lists,
+                                     file->details->directory,
+                                     file);
         }
         unref_list = g_list_concat (unref_list, affected_files);
 
@@ -1601,12 +1600,8 @@ nautilus_directory_notify_files_moved (GList *file_pairs)
         }
         else
         {
-            NautilusDirectory *directory;
-
-            directory = nautilus_file_get_directory (file);
-
             /* Handle notification in the old directory. */
-            old_directory = directory;
+            old_directory = file->details->directory;
             collect_parent_directories (parent_directories, old_directory);
 
             /* Cancel loading of attributes in the old directory */
