@@ -35,6 +35,7 @@ typedef enum {
 	NAUTILUS_FILE_UNDO_OP_MOVE,
 	NAUTILUS_FILE_UNDO_OP_RENAME,
 	NAUTILUS_FILE_UNDO_OP_BATCH_RENAME,
+	NAUTILUS_FILE_UNDO_OP_FAVORITES,
 	NAUTILUS_FILE_UNDO_OP_CREATE_EMPTY_FILE,
 	NAUTILUS_FILE_UNDO_OP_CREATE_FILE_FROM_TEMPLATE,
 	NAUTILUS_FILE_UNDO_OP_CREATE_FOLDER,
@@ -217,6 +218,31 @@ void nautilus_file_undo_info_batch_rename_set_data_pre (NautilusFileUndoInfoBatc
 void nautilus_file_undo_info_batch_rename_set_data_post (NautilusFileUndoInfoBatchRename *self,
 						         GList                           *new_files);
 
+/* favorite files */
+#define NAUTILUS_TYPE_FILE_UNDO_INFO_FAVORITES         (nautilus_file_undo_info_favorites_get_type ())
+#define NAUTILUS_FILE_UNDO_INFO_FAVORITES(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_FILE_UNDO_INFO_FAVORITES, NautilusFileUndoInfoFavorites))
+#define NAUTILUS_FILE_UNDO_INFO_FAVORITES_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), NAUTILUS_TYPE_FILE_UNDO_INFO_FAVORITES, NautilusFileUndoInfoFavoritesClass))
+#define NAUTILUS_IS_FILE_UNDO_INFO_FAVORITES(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), NAUTILUS_TYPE_FILE_UNDO_INFO_FAVORITES))
+#define NAUTILUS_IS_FILE_UNDO_INFO_FAVORITES_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), NAUTILUS_TYPE_FILE_UNDO_INFO_FAVORITES))
+#define NAUTILUS_FILE_UNDO_INFO_FAVORITES_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), NAUTILUS_TYPE_FILE_UNDO_INFO_FAVORITES, NautilusFileUndoInfoFavoritesClass))
+
+typedef struct _NautilusFileUndoInfoFavorites      NautilusFileUndoInfoFavorites;
+typedef struct _NautilusFileUndoInfoFavoritesClass NautilusFileUndoInfoFavoritesClass;
+typedef struct _NautilusFileUndoInfoFavoritesDetails NautilusFileUndoInfoFavoritesDetails;
+
+struct _NautilusFileUndoInfoFavorites {
+    NautilusFileUndoInfo parent;
+    NautilusFileUndoInfoFavoritesDetails *priv;
+};
+
+struct _NautilusFileUndoInfoFavoritesClass {
+    NautilusFileUndoInfoClass parent_class;
+};
+
+GType nautilus_file_undo_info_favorites_get_type (void) G_GNUC_CONST;
+NautilusFileUndoInfo *nautilus_file_undo_info_favorites_new (GList   *files,
+                                                             gboolean starred);
+
 /* trash */
 #define NAUTILUS_TYPE_FILE_UNDO_INFO_TRASH         (nautilus_file_undo_info_trash_get_type ())
 #define NAUTILUS_FILE_UNDO_INFO_TRASH(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_FILE_UNDO_INFO_TRASH, NautilusFileUndoInfoTrash))
