@@ -322,7 +322,10 @@ nautilus_compute_title_for_location (GFile *location)
         {
             title = g_strdup (_("Other Locations"));
         }
-        else
+        else if (nautilus_file_is_favorite_location (file))
+        {
+            title = g_strdup (_("Starred"));
+        }
         {
             title = nautilus_file_get_description (file);
 
@@ -593,22 +596,16 @@ nautilus_is_search_directory (GFile *dir)
 }
 
 gboolean
-nautilus_is_recent_directory (GFile *dir)
+nautilus_is_favorite_directory (GFile *dir)
 {
     g_autofree gchar *uri = NULL;
 
     uri = g_file_get_uri (dir);
 
-    return eel_uri_is_recent (uri);
-}
+    if (eel_uri_is_favorites (uri))
+        return TRUE;
 
-gboolean
-nautilus_is_trash_directory (GFile *dir)
-{
-    g_autofree gchar *uri = NULL;
-
-    uri = g_file_get_uri (dir);
-    return eel_uri_is_trash (uri);
+    return FALSE;
 }
 
 gboolean
@@ -623,7 +620,7 @@ nautilus_is_other_locations_directory (GFile *dir)
 GMount *
 nautilus_get_mounted_mount_for_root (GFile *location)
 {
-    g_autoptr (GVolumeMonitor) volume_monitor = NULL;
+    GVolumeMonitor *volume_monitor;
     GList *mounts;
     GList *l;
     GMount *mount;
@@ -1306,135 +1303,54 @@ nautilus_file_selection_equal (GList *selection_a,
     return selection_matches;
 }
 
-static char *
-trim_whitespace (const gchar *string)
-{
-    glong space_count;
-    glong length;
-    gchar *offset;
-
-    space_count = 0;
-    length = g_utf8_strlen (string, -1);
-    offset = g_utf8_offset_to_pointer (string, length);
-
-    while (space_count <= length)
-    {
-        gunichar character;
-
-        offset = g_utf8_prev_char (offset);
-        character = g_utf8_get_char (offset);
-
-        if (!g_unichar_isspace (character))
-        {
-            break;
-        }
-
-        space_count++;
-    }
-
-    if (space_count == 0)
-    {
-        return g_strdup (string);
-    }
-
-    return g_utf8_substring (string, 0, length - space_count);
-}
-
 char *
 nautilus_get_common_filename_prefix (GList *file_list,
                                      int    min_required_len)
 {
-    GList *file_names = NULL;
-    GList *directory_names = NULL;
-    char *result_files;
-    g_autofree char *result = NULL;
-    g_autofree char *result_trimmed = NULL;
+    GList *l;
+    GList *strs = NULL;
+    char *name;
+    char *result;
 
     if (file_list == NULL)
     {
         return NULL;
     }
 
-    for (GList *l = file_list; l != NULL; l = l->next)
+    for (l = file_list; l != NULL; l = l->next)
     {
-        char *name;
-
         g_return_val_if_fail (NAUTILUS_IS_FILE (l->data), NULL);
 
         name = nautilus_file_get_display_name (l->data);
-
-        /* Since the concept of file extensions does not apply to directories,
-         * we filter those out.
-         */
-        if (nautilus_file_is_directory (l->data))
-        {
-            directory_names = g_list_prepend (directory_names, name);
-        }
-        else
-        {
-            file_names = g_list_prepend (file_names, name);
-        }
+        strs = g_list_append (strs, name);
     }
 
-    result_files = nautilus_get_common_filename_prefix_from_filenames (file_names, min_required_len);
+    result = nautilus_get_common_filename_prefix_from_filenames (strs, min_required_len);
+    g_list_free_full (strs, g_free);
 
-    if (directory_names == NULL)
-    {
-        return result_files;
-    }
-
-    if (result_files != NULL)
-    {
-        directory_names = g_list_prepend (directory_names, result_files);
-    }
-
-    result = eel_str_get_common_prefix (directory_names, min_required_len);
-
-    g_list_free_full (file_names, g_free);
-    g_list_free_full (directory_names, g_free);
-
-    if (result == NULL)
-    {
-        return NULL;
-    }
-
-    result_trimmed = trim_whitespace (result);
-
-    if (g_utf8_strlen (result_trimmed, -1) < min_required_len)
-    {
-        return NULL;
-    }
-
-    return g_steal_pointer (&result_trimmed);
+    return result;
 }
 
 char *
 nautilus_get_common_filename_prefix_from_filenames (GList *filenames,
                                                     int    min_required_len)
 {
-    GList *stripped_filenames = NULL;
     char *common_prefix;
     char *truncated;
     int common_prefix_len;
 
-    for (GList *i = filenames; i != NULL; i = i->next)
-    {
-        gchar *stripped_filename;
+    common_prefix = eel_str_get_common_prefix (filenames, min_required_len);
 
-        stripped_filename = eel_filename_strip_extension (i->data);
-
-        stripped_filenames = g_list_prepend (stripped_filenames, stripped_filename);
-    }
-
-    common_prefix = eel_str_get_common_prefix (stripped_filenames, min_required_len);
     if (common_prefix == NULL)
     {
         return NULL;
     }
 
-    g_list_free_full (stripped_filenames, g_free);
+    truncated = eel_filename_strip_extension (common_prefix);
+    g_free (common_prefix);
+    common_prefix = truncated;
 
-    truncated = trim_whitespace (common_prefix);
+    truncated = eel_str_rtrim_punctuation (common_prefix);
     g_free (common_prefix);
 
     common_prefix_len = g_utf8_strlen (truncated, -1);
