@@ -45,8 +45,7 @@ gboolean nautilus_is_home_directory_file             (GFile *dir,
 						      const char *filename);
 gboolean nautilus_is_in_system_dir                   (GFile *location);
 gboolean nautilus_is_search_directory                (GFile *dir);
-gboolean nautilus_is_recent_directory                (GFile *dir);
-gboolean nautilus_is_trash_directory                 (GFile *dir);
+gboolean nautilus_is_favorite_directory              (GFile *dir);
 gboolean nautilus_is_other_locations_directory       (GFile *dir);
 GMount * nautilus_get_mounted_mount_for_root         (GFile *location);
 
