@@ -47,7 +47,8 @@ typedef enum
     OTHER_LOCATIONS_BUTTON,
     ROOT_BUTTON,
     HOME_BUTTON,
-    MOUNT_BUTTON
+    MOUNT_BUTTON,
+    FAVORITE_LOCATION_BUTTON
 } ButtonType;
 
 #define BUTTON_DATA(x) ((ButtonData *) (x))
@@ -454,6 +455,11 @@ get_dir_name (ButtonData *button_data)
             return _("Other Locations");
         }
 
+        case FAVORITE_LOCATION_BUTTON:
+        {
+            return _("Starred");
+        }
+
         default:
             return button_data->dir_name;
     }
@@ -1924,6 +1930,10 @@ setup_button_type (ButtonData      *button_data,
 
         g_object_unref (mount);
     }
+    else if (nautilus_is_favorite_directory (location))
+    {
+        button_data->type = FAVORITE_LOCATION_BUTTON;
+    }
     else
     {
         button_data->type = NORMAL_BUTTON;
