@@ -24,6 +24,7 @@
 #include "nautilus-search-provider.h"
 #include "nautilus-search-engine-simple.h"
 #include "nautilus-ui-utilities.h"
+#include "nautilus-tag-manager.h"
 #define DEBUG_FLAG NAUTILUS_DEBUG_SEARCH
 #include "nautilus-debug.h"
 
@@ -219,9 +220,11 @@ visit_directory (GFile            *dir,
     gboolean visited;
     guint64 atime;
     guint64 mtime;
+    GPtrArray *date_range;
     GDateTime *initial_date;
     GDateTime *end_date;
-
+    NautilusTagManager *tag_manager;
+    gchar *uri;
 
     enumerator = g_file_enumerate_children (dir,
                                             data->mime_types != NULL ?
@@ -240,8 +243,6 @@ visit_directory (GFile            *dir,
 
     while ((info = g_file_enumerator_next_file (enumerator, data->cancellable, NULL)) != NULL)
     {
-        g_autoptr (GPtrArray) date_range = NULL;
-
         display_name = g_file_info_get_display_name (info);
         if (display_name == NULL)
         {
@@ -297,13 +298,27 @@ visit_directory (GFile            *dir,
             found = nautilus_file_date_in_between (current_file_time,
                                                    initial_date,
                                                    end_date);
+            g_ptr_array_unref (date_range);
+        }
+
+        if (nautilus_query_get_search_favorite (data->query))
+        {
+            tag_manager = nautilus_tag_manager_get ();
+
+            uri = g_file_get_uri (child);
+
+            if (!nautilus_tag_manager_file_is_favorite (tag_manager, uri))
+            {
+                found = FALSE;
+            }
+
+            g_free (uri);
         }
 
         if (found)
         {
             NautilusSearchHit *hit;
             GDateTime *date;
-            char *uri;
 
             uri = g_file_get_uri (child);
             hit = nautilus_search_hit_new (uri);
